@@ -784,6 +784,7 @@ where
             Value::Function(n) => emit!(self, n),
             Value::SimpleBlock(n) => emit!(self, n),
             Value::Dimension(n) => emit!(self, n),
+            Value::Integer(n) => emit!(self, n),
             Value::Number(n) => emit!(self, n),
             Value::Percentage(n) => emit!(self, n),
             Value::Ratio(n) => emit!(self, n),
@@ -794,7 +795,7 @@ where
             Value::CalcSum(n) => emit!(self, n),
             Value::Url(n) => emit!(self, n),
             Value::Delimiter(n) => emit!(self, n),
-            Value::Urange(n) => emit!(self, n),
+            Value::UnicodeRange(n) => emit!(self, n),
             Value::ComplexSelector(n) => emit!(self, n),
             Value::PreservedToken(n) => emit!(self, n),
         }
@@ -1119,6 +1120,15 @@ where
         emit!(self, n.unit);
     }
 
+    #[emitter]
+    fn emit_integer(&mut self, n: &Integer) -> Result {
+        if self.config.minify {
+            self.wr.write_raw(Some(n.span), &n.value.to_string())?;
+        } else {
+            self.wr.write_raw(Some(n.span), &n.raw)?;
+        }
+    }
+
     #[emitter]
     fn emit_number(&mut self, n: &Number) -> Result {
         if self.config.minify {
@@ -1498,8 +1508,19 @@ where
     }
 
     #[emitter]
-    fn emit_urange(&mut self, n: &Urange) -> Result {
-        self.wr.write_raw(Some(n.span), &n.value)?;
+    fn emit_unicode_range(&mut self, n: &UnicodeRange) -> Result {
+        let mut value = String::new();
+
+        value.push(n.prefix);
+        value.push('+');
+        value.push_str(&n.start);
+
+        if let Some(end) = &n.end {
+            value.push('-');
+            value.push_str(end);
+        }
+
+        self.wr.write_raw(Some(n.span), &value)?;
     }
 
     #[emitter]
